import * as React from 'react';

interface Prop {
  steps: any[];
  stepComponent?: any;
  onSelection?: (selectedStep: any) => void;
  className?: string;
  history?: any;
  preventDefaultStyles?: boolean;
}

const getOrElse = (value: any, fallback: any) => {
  if (value === undefined || value === null) return fallback;

  return value;
};

class BreadCrumb extends React.Component<Prop> {

  componentDidMount(): void {
    if (!this.props.preventDefaultStyles) {
      // @ts-ignore
      import('../styles/index.css');
    }
  }

  static getDefaultStep(step: any, idx: number) {
    return (
      <div style={{ all: 'inherit' }}>
        <span>{getOrElse(step.sign, idx + 1)}</span>
        <button className="step__symbol">
          <span>{'●'}</span>
          <div className="step__symbol__line" />
        </button>
        <span>{step.name}</span>
      </div>
    );
  }

  handleStepSelection(selectedStep: any) {
    return () => {

      if (selectedStep.isDisabled) return;

      const { history = null, onSelection = null } = this.props;

      if (history) {
        history.push(selectedStep.url, history.state);
      }

      if (onSelection) {
        onSelection(selectedStep);
      }
    };
  }

  render() {
    const { steps = [], stepComponent = null, className = '' } = this.props;

    return (
      <div className={`bread-crumb-container ${className}`}>
        {
          steps.map((step: any, idx: number) => (
            <div
              className={`each-step${step.isDisabled ? ' --step-disabled' : ' --step-enabled'}`}
              key={getOrElse(step.key, idx)}
              onClick={this.handleStepSelection(step)}
            >
              {
                !!stepComponent
                  ? stepComponent(step, idx)
                  : BreadCrumb.getDefaultStep(step, idx)
              }
            </div>
          ))
        }
      </div>
    );
  }
}

export default BreadCrumb;
